OH_AudioStreamBuilder_SetWriteDataWithMetadataCallback

Function OH_AudioStreamBuilder_SetWriteDataWithMetadataCallback 

pub unsafe extern "C" fn OH_AudioStreamBuilder_SetWriteDataWithMetadataCallback(
    builder: *mut OH_AudioStreamBuilder,
    callback: OH_AudioRenderer_WriteDataWithMetadataCallback,
    userData: *mut c_void,
) -> OH_AudioStream_Result
@brief Set the callback of writing metadata to the renderer client

@since 12

@param builder Reference provided by OH_AudioStreamBuilder_Create() @param callback Callback to the functions that will write audio data with metadata to the renderer. @param userData Pointer to an application data structure that will be passed to the callback functions. @return Function result code: {@link AUDIOSTREAM_SUCCESS} If the execution is successful. {@link AUDIOSTREAM_ERROR_INVALID_PARAM}: 1.The param of builder is nullptr; 2.StreamType invalid.